@@ -21,9 +21,7 @@
 #
 import os
 import sys
-from datetime import date, time
 from decimal import Decimal
-from binascii import hexlify
 
 from storm.tracer import trace
 from storm.databases import dummy
@@ -35,8 +33,11 @@ if not os.environ.get("NLS_LANG", None):
     os.environ["NLS_LANG"] = 'american_america.utf8'
 try:
     import cx_Oracle as oracle
-except:
+except Exception, e:
     oracle = dummy
+    from traceback import format_exc
+    sys.stderr.write('Encountered an error importing cx_Oracle')
+    sys.stderr.write(format_exc())
 
 from storm.variables import Variable, RawStrVariable, PickleVariable
 from storm.database import Database, Connection, Result
